KeyPackage

Type Alias KeyPackage 

pub type KeyPackage = KeyPackage<Secp256K1Sha256>;
A FROST(secp256k1, SHA-256) keypair, which can be generated either by a trusted dealer or using a DKG.

When using a central dealer, SecretShares are distributed to participants, who then perform verification, before deriving KeyPackages, which they store to later use during signing.

Aliased Type

pub struct KeyPackage { /* private fields */ }