pub fn commit<RNG>(
secret: &SigningShare<Secp256K1Sha256>,
rng: &mut RNG,
) -> (SigningNonces<Secp256K1Sha256>, SigningCommitments<Secp256K1Sha256>)Expand description
Performed once by each participant selected for the signing operation.
Generates the signing nonces and commitments to be used in the signing operation.