pub type SigningPackage = SigningPackage<Secp256K1Sha256>;Expand description
Generated by the coordinator of the signing operation and distributed to each signing party.
Aliased Type
pub struct SigningPackage { /* private fields */ }pub type SigningPackage = SigningPackage<Secp256K1Sha256>;Generated by the coordinator of the signing operation and distributed to each signing party.
pub struct SigningPackage { /* private fields */ }